@@ -11,7 +11,7 @@
 """
 index unit tests
 
-$Id: testIndex.py 2054 2009-03-14 10:11:29Z ajung $
+$Id: testIndex.py 2160 2009-03-17 17:07:30Z ajung $
 """
 
 import os
@@ -403,6 +403,12 @@ class FunctionalTest(TextIndexNGTestCase):
             self.assertEqual(result, True)
 
 
+class LegacyTests(TextIndexNGTestCase):
+
+    def testLegacyImports(self):
+        from textindexng import index
+        from textindexng import parsers
+
 def test_suite():
     s = unittest.TestSuite()
     s.addTest(unittest.makeSuite(ContentCollectorTests))
@@ -412,6 +418,7 @@ def test_suite():
     s.addTest(unittest.makeSuite(StemmerTests))
     s.addTest(unittest.makeSuite(MultilingualTests))
     s.addTest(unittest.makeSuite(FunctionalTest))
+    s.addTest(unittest.makeSuite(LegacyTests))
     return s
 
 def main():
